@@ -1,5 +1,3 @@
-package Kvasir::Engine;
-
 use strict;
 use warnings;
 
@@ -58,14 +56,4 @@ sub add_post_hook {
 }
 
 1;
-__END__
-
-=head1 NAME
-
-Kvasir::Engine (Hook) - Hook management
-
-=head1 SEE ALSO
-
-L<Kvasir::Engine>.
-
-=cut
\ No newline at end of file
+__END__
\ No newline at end of file
