@@ -56,6 +56,30 @@ __END__
 
 Kvasir::InputHandler - Handles input retrieval
 
+=head1 SYNOPSIS
+
+  package MyApp::Rule;
+  
+  use base qw(Kvasir::Rule);
+  
+  # ... constructors etc ...
+  
+  sub evaluate {
+      # Retrieve the current input handler for the executing engine
+      my ($input) = @_[KV_INPUT];
+      
+      # Retrieve the current value from the input 'some_input' 
+      if ($input->get("some_input") > 10) {
+          return KV_MATCH;
+      }
+      
+      return KV_NO_MATCH;
+  }
+  
+=head1 DESCRIPTION
+
+This class handles input retrieval for an engine. It should not be instanciated by users.
+
 =head1 INTERFACE
 
 =head2 CLASS METHODS
@@ -78,6 +102,4 @@ Retrieves the value from the input whose name is I<INPUT>. If the input does not
 
 =back
 
-None
-
 =cut
